<?php

global $chpass_text;
$chpass_text = array (

'changeyourpass'=>  'Ändern Sie Ihr Passwort',
'current'       =>  'Altes Passwort',
'new'           =>  'Neues Passwort',
'confirm'       =>  'Neues Passwort bestätigen',
'savepass'      =>  'Passwort speichern',
'nopermission'  =>  'Sie sind nicht berechtigt, diese Seite zu verwenden.',

);
?>
